netapp_ontap.models.shelf_ports API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.shelf_ports`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ShelfPortsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ShelfPorts object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cable: ShelfPortsCable GET POST PATCH`

    The cable field of the shelf_ports.

  `designator: str GET POST PATCH`

    The designator field of the shelf_ports.

    Valid choices:

    - circle
    - square
    - 1
    - 2
    - 3
    - 4
  `id: Size GET POST PATCH`

    The id field of the shelf_ports.

    Example: 0

  `internal: bool GET POST PATCH`

    The internal field of the shelf_ports.

  `mac_address: str GET POST PATCH`

    The mac_address field of the shelf_ports.

  `module_id: str GET POST PATCH`

    The module_id field of the shelf_ports.

    Valid choices:

    - a
    - b
  `remote: ShelfPortsRemote GET POST PATCH`

    The remote field of the shelf_ports.

  `speed: Size GET POST PATCH`

    The speed field of the shelf_ports.

    Example: 100

  `state: str GET POST PATCH`

    The state field of the shelf_ports.

    Valid choices:

    - connected
    - disconnected
    - error
  `wwn: str GET POST PATCH`

    The wwn field of the shelf_ports.

    Example: 500A0980000B6C3F